Ocyan plugin oscar_address
==========================

About oscar_address
-------------------
Allows for the configuration of the billing address form and adds the "house number" field.

Installation
------------
Add `ocyan.plugin.oscar_address` to your projects dependencies.
